      SUBROUTINE CGLALO (OLDLAT, OLDLON, CGLAT, CGLON)
C-----------------------------------------------------------------------
C
C     THIS SUBROUTINE IS THE HAKURA/GUSTAFSSON COORDINATE TRANSFORMATION
C     OF GEOGRAPHIC LATITUDE AND LONGITUDE TO COORECTED GEOMAGNETIC
C     LATITUDE AND LONGITUDE.
C
C     RE: A REVISED CORRECTED GEOMAGNETIC COORDINATE SYSTEM,
C         KGO REPORT NO. 694 (APRIL 1969), KIRUNA GEOPHYSICAL 
C         OBSERVATORY, S-981 01 KIRUNA 1, SWEDEN. (BASED ON IGRF65
C         MODEL)
C
C     THIS ROUTINE HAS BEEN CORRECTED AND UPDATED BY MAURIZIO CANDIDI
C     AND HERBERT KROEHL OF USDOC/NOAA/DSD, BOULDER, CO 80303.
C     THIS ROUTINE HAS BEEN CORRECTED TO ALLOW CALCULATION OF CGM
C     COORDINATES RIGHT UP TO THE GEOGRAPHIC POLES. RKR 80/02/20.
C                            R. K. ROSICH, USDOC/NTIA/ITS, 79/02/23.
C
C     MODIFIED TO USE ARGUMENTS BASED ON IGRF80 PRESENTED BY GUSTAFSSON
C     AT CHAPMAN CONF.,IRVINGTON,VA, APRIL 83.  DISCONTINUITIES IN HIS
C     TABLE HAVE BEEN REMOVED BY CURVE FITTING.
C           F. J. RICH, A.F. GEOPHYS LAB., BEDFORD, MA 01731 AUG 83 
C
C     GEOMAGNETIC LATITUDE AND LONGITUDE COORDINATES PREVIOUSLY
C     OMITTED IN THE EQUATORIAL REGION BETWEEN +22 DEGREES AND
C     -10 DEGREES GEOGRAPHIC LATITUDE (INCLUSIVE) WERE OBTAINED
C     BY APPLYING A SMOOTH CUBIC REGRESSION ACROSS THE NULL REGION.
C     THIS INTERPOLATION WAS PERFORMED BY RADEX,INC., OCTOBER,1983.
C
C-----------------------------------------------------------------------
C     MODIFIED TO USE ARGUMENTS BASED ON IGRF 2000 MODEL. THE
C     COORDINATES IN THE AREA OF THE SOUTH ATLANTIC ANOMALY AND THE
C     DIP EQUATOR HAVE BEEN FURTHER CORRECTED BY A RESAMPLING OF POINTS
C     BASED ON SMOOTHED DERIVATIVES BETWEEN CG POINTS.
C
C     THIS VERSION DOES NOT CONTAIN THE POLAR TRIANGULATION SCHEME AS
C     SEEN IN EARLIER VERSIONS. AN UPDATED EARLIER VERSION DOES EXIST.
C
C                                  W. HERES, AER INC., AUGUST 2006
C-----------------------------------------------------------------------
C
C     ARGUMENTS:
C        INPUT:
C           OLDLAT = GEOGRAPHIC LATITUDE (DEGREES, +=N, -=S),
C           OLDLON = GEOGRAPHIC LONGITUDE (DEGREES E. LONG.),
C        OUTPUT:
C           CGLAT = CORRECTED GEOMAGNETIC LATITUDE (DEGREES, +=N, -=S),
C           CGLON = CORRECTED GEOMAGNETIC LONGITUDE (DEGREES E. LONG.).
C
C           THE TABLE OF CORRECTED GEOMAGNETIC LATITUDE (2 DEG STEP)
C           AND LONGITUDE (10 DEG STEP) PAIRS IS FOUND IN ARRAY A.
C
C-----------------------------------------------------------------------
C     Updated with points generated from the IGRF2000 model. Based on
C     previous work of C. A. Hein of Radex, Inc.
C
C     UPDATED BY:
C
C     Steve O'Malley
C     AER, Inc.
C     131 Hartwell Avenue
C     Lexington, MA 02421
C     somalley@aer.com
C
C     NOTE: This is not the original CGLALO 2000 epoch file. It was rebuilt
C           using the Will Heres 2005 epoch Fortran file (code) and a routine by
C           Angeline Burrell (A array data) that had converted the original
C           CGLALO 2000 epoch Fortran file to C. This rebuild was done simply
C           for consistency since the epoch 2000 block data (spherical harmonic
C           version of the AACGM conversion) file was available when the AACGM
C           section of the AER Space Weather website was created. This in no way
C           affects the accuracy of this coordinate conversion based on the 2000
C           epoch IGRF. 
C
C-----------------------------------------------------------------------

      IMPLICIT REAL*8(A-H,O-Z)
      DIMENSION A(2,36,89)

      DATA CGMNLA,CGMNLO/  82.82, 170.45/ CGMSLA,CGMSLO/ -74.00,  18.87/
C 
C
      DATA((A(I,J,  1),I=1,2),J=1,36)/
     $  82.83,153.18, 82.54,153.75, 82.27,154.72, 82.01,156.08,
     $  81.79,157.71, 81.59,159.58, 81.42,161.67, 81.29,163.92,
     $  81.19,166.24, 81.12,168.65, 81.09,171.07, 81.10,173.48,
     $  81.15,175.82, 81.24,178.06, 81.36,180.16, 81.52,182.09,
     $  81.71,183.79, 81.94,185.23, 82.20,186.32, 82.48,187.06,
     $  82.78,187.36, 83.09,187.14, 83.40,186.38, 83.71,184.97,
     $  83.98,182.94, 84.21,180.25, 84.39,176.97, 84.50,173.30,
     $  84.54,169.41, 84.50,165.55, 84.39,162.00, 84.21,158.95,
     $  83.98,156.49, 83.72,154.73, 83.43,153.59, 83.13,153.13/
C
      DATA((A(I,J,  2),I=1,2),J=1,36)/
     $  82.24,137.28, 81.71,139.33, 81.24,141.89, 80.82,144.85,
     $  80.45,148.11, 80.14,151.65, 79.88,155.41, 79.67,159.33,
     $  79.52,163.34, 79.42,167.39, 79.37,171.48, 79.37,175.52,
     $  79.43,179.49, 79.54,183.34, 79.72,187.01, 79.96,190.48,
     $  80.27,193.69, 80.65,196.61, 81.09,199.16, 81.60,201.28,
     $  82.16,202.86, 82.77,203.78, 83.42,203.82, 84.09,202.72,
     $  84.74,200.08, 85.34,195.42, 85.84,188.27, 86.16,178.62,
     $  86.26,167.36, 86.11,156.49, 85.75,147.68, 85.24,141.50,
     $  84.66,137.66, 84.03,135.75, 83.41,135.25, 82.81,135.85/
C
      DATA((A(I,J,  3),I=1,2),J=1,36)/
     $  81.16,124.41, 80.48,128.08, 79.88,132.08, 79.37,136.39,
     $  78.93,140.98, 78.56,145.79, 78.25,150.81, 78.01,155.96,
     $  77.83,161.19, 77.70,166.48, 77.63,171.76, 77.62,177.01,
     $  77.67,182.16, 77.78,187.16, 77.97,191.99, 78.25,196.60,
     $  78.61,200.97, 79.08,205.08, 79.64,208.89, 80.30,212.35,
     $  81.07,215.43, 81.92,218.02, 82.87,219.99, 83.87,221.02,
     $  84.92,220.60, 85.98,217.59, 86.98,209.57, 87.75,191.60,
     $  87.97,161.90, 87.50,136.30, 86.64,123.33, 85.65,117.94,
     $  84.65,116.39, 83.68,116.92, 82.77,118.69, 81.93,121.25/
C
      DATA((A(I,J,  4),I=1,2),J=1,36)/
     $  79.76,114.68, 78.98,119.55, 78.31,124.68, 77.75,130.01,
     $  77.27,135.59, 76.88,141.33, 76.57,147.27, 76.32,153.35,
     $  76.12,159.54, 75.98,165.76, 75.89,171.98, 75.86,178.14,
     $  75.88,184.19, 75.98,190.07, 76.16,195.75, 76.43,201.21,
     $  76.82,206.43, 77.33,211.41, 77.97,216.16, 78.74,220.68,
     $  79.65,225.00, 80.68,229.11, 81.84,233.03, 83.11,236.71,
     $  84.47,240.14, 85.89,243.01, 87.37,244.68, 88.85,240.35,
     $  89.51,114.83, 88.09, 91.36, 86.65, 91.53, 85.27, 94.22,
     $  83.97, 97.65, 82.75,101.47, 81.64,105.61, 80.64,110.02/
C
      DATA((A(I,J,  5),I=1,2),J=1,36)/
     $  78.13,107.36, 77.30,113.13, 76.60,119.02, 76.01,125.11,
     $  75.53,131.38, 75.14,137.85, 74.83,144.49, 74.59,151.28,
     $  74.40,158.19, 74.25,165.18, 74.14,172.15, 74.08,179.04,
     $  74.08,185.80, 74.14,192.37, 74.29,198.71, 74.54,204.80,
     $  74.93,210.64, 75.46,216.25, 76.14,221.67, 76.99,226.96,
     $  78.01,232.18, 79.18,237.44, 80.50,242.87, 81.94,248.69,
     $  83.49,255.31, 85.10,263.71, 86.71,276.68, 88.12,304.84,
     $  88.45,  9.73, 87.29, 50.35, 85.78, 66.74, 84.25, 76.41,
     $  82.79, 83.72, 81.44, 90.06, 80.20, 95.95, 79.10,101.66/
C
      DATA((A(I,J,  6),I=1,2),J=1,36)/
     $  76.37,101.79, 75.50,108.17, 74.78,114.61, 74.20,121.22,
     $  73.73,127.99, 73.36,134.99, 73.07,142.18, 72.85,149.56,
     $  72.66,157.09, 72.52,164.69, 72.41,172.31, 72.31,179.84,
     $  72.26,187.22, 72.28,194.36, 72.38,201.24, 72.59,207.77,
     $  72.96,214.03, 73.49,220.09, 74.21,225.97, 75.12,231.79,
     $  76.22,237.65, 77.50,243.72, 78.95,250.19, 80.52,257.44,
     $  82.18,266.13, 83.86,277.54, 85.42,294.56, 86.56,322.66,
     $  86.72,  1.32, 85.82, 32.83, 84.40, 52.08, 82.85, 64.67,
     $  81.31, 74.06, 79.87, 81.88, 78.56, 88.85, 77.38, 95.40/
C
      DATA((A(I,J,  7),I=1,2),J=1,36)/
     $  74.50, 97.46, 73.61,104.21, 72.88,111.02, 72.31,117.93,
     $  71.87,125.17, 71.53,132.64, 71.27,140.33, 71.07,148.21,
     $  70.90,156.24, 70.75,164.35, 70.61,172.46, 70.49,180.47,
     $  70.40,188.29, 70.36,195.86, 70.41,203.13, 70.58,210.09,
     $  70.92,216.76, 71.44,223.20, 72.17,229.48, 73.15,235.61,
     $  74.33,241.91, 75.70,248.52, 77.25,255.70, 78.93,263.88,
     $  80.67,273.72, 82.38,286.48, 83.88,304.24, 84.87,329.13,
     $  84.96,358.78, 84.16, 24.75, 82.80, 43.49, 81.25, 56.94,
     $  79.66, 67.28, 78.15, 75.89, 76.77, 83.51, 75.55, 90.62/
C
      DATA((A(I,J,  8),I=1,2),J=1,36)/
     $  72.51, 93.92, 71.63,101.01, 70.93,108.20, 70.39,115.54,
     $  69.98,123.10, 69.67,130.89, 69.44,138.92, 69.26,147.16,
     $  69.10,155.57, 68.95,164.08, 68.79,172.58, 68.64,180.99,
     $  68.51,189.19, 68.42,197.11, 68.42,204.69, 68.55,211.93,
     $  68.85,218.87, 69.36,225.56, 70.10,232.11, 71.09,238.65,
     $  72.31,245.33, 73.81,252.28, 75.46,259.96, 77.22,268.71,
     $  79.03,279.21, 80.77,292.49, 82.23,309.98, 83.13,332.43,
     $  83.19,357.55, 82.41, 20.28, 81.09, 38.07, 79.51, 51.63,
     $  77.88, 62.39, 76.32, 71.43, 74.88, 79.42, 73.61, 86.85/
C
      DATA((A(I,J,  9),I=1,2),J=1,36)/
     $  70.52, 91.24, 69.65, 98.57, 68.97,105.98, 68.45,113.57,
     $  68.07,121.37, 67.79,129.42, 67.58,137.74, 67.42,146.28,
     $  67.27,155.01, 67.12,163.84, 66.96,172.68, 66.78,181.41,
     $  66.61,189.93, 66.47,198.13, 66.42,205.98, 66.50,213.45,
     $  66.77,220.60, 67.26,227.50, 68.01,234.26, 69.02,241.01,
     $  70.30,247.94, 71.82,255.27, 73.58,263.29, 75.44,272.43,
     $  77.31,283.30, 79.07,296.75, 80.51,313.74, 81.36,334.41,
     $  81.39,356.83, 80.63, 17.47, 79.31, 34.41, 77.71, 47.83,
     $  76.03, 58.74, 74.40, 67.99, 72.90, 76.20, 71.59, 83.84/
C
      DATA((A(I,J, 10),I=1,2),J=1,36)/
     $  68.49, 89.05, 67.63, 96.54, 66.96,104.13, 66.47,111.89,
     $  66.12,119.90, 65.88,128.18, 65.70,136.73, 65.56,145.53,
     $  65.43,154.53, 65.28,163.63, 65.10,172.75, 64.90,181.75,
     $  64.69,190.53, 64.50,198.97, 64.40,207.04, 64.44,214.70,
     $  64.67,222.03, 65.16,229.09, 65.91,236.02, 66.94,242.96,
     $  68.26,250.09, 69.84,257.64, 71.62,265.90, 73.58,275.36,
     $  75.53,286.44, 77.32,299.89, 78.75,316.36, 79.57,335.76,
     $  79.58,356.39, 78.82, 15.59, 77.48, 31.79, 75.84, 45.02,
     $  74.10, 55.95, 72.38, 65.35, 70.87, 73.70, 69.57, 81.50/
C
      DATA((A(I,J, 11),I=1,2),J=1,36)/
     $  66.42, 87.19, 65.56, 94.79, 64.93,102.53, 64.47,110.47,
     $  64.16,118.67, 63.95,127.15, 63.80,135.90, 63.68,144.91,
     $  63.56,154.12, 63.41,163.45, 63.22,172.80, 62.99,182.04,
     $  62.74,191.04, 62.51,199.69, 62.35,207.94, 62.35,215.77,
     $  62.55,223.24, 63.02,230.43, 63.79,237.50, 64.86,244.59,
     $  66.21,251.89, 67.83,259.60, 69.68,268.05, 71.66,277.61,
     $  73.69,288.89, 75.52,302.29, 76.96,318.31, 77.76,336.72,
     $  77.76,356.08, 76.98, 14.23, 75.62, 29.87, 73.93, 42.90,
     $  72.10, 53.88, 70.39, 63.23, 68.84, 71.65, 67.51, 79.54/
C
      DATA((A(I,J, 12),I=1,2),J=1,36)/
     $  64.30, 85.60, 63.48, 93.33, 62.87,101.19, 62.46,109.28,
     $  62.18,117.64, 61.99,126.28, 61.87,135.20, 61.77,144.38,
     $  61.66,153.77, 61.51,163.29, 61.32,172.83, 61.07,182.27,
     $  60.78,191.47, 60.50,200.30, 60.29,208.71, 60.24,216.68,
     $  60.42,224.26, 60.88,231.57, 61.65,238.76, 62.75,245.98,
     $  64.15,253.42, 65.84,261.29, 67.72,269.85, 69.75,279.52,
     $  71.80,290.74, 73.69,304.15, 75.14,319.79, 75.94,337.46,
     $  75.92,355.86, 75.13, 13.25, 73.72, 28.45, 71.96, 41.37,
     $  70.12, 52.12, 68.35, 61.48, 66.75, 69.93, 65.38, 77.86/
C
      DATA((A(I,J, 13),I=1,2),J=1,36)/
     $  62.17, 84.25, 61.37, 92.06, 60.80,100.04, 60.42,108.25,
     $  60.18,116.75, 60.03,125.54, 59.92,134.62, 59.84,143.94,
     $  59.74,153.47, 59.59,163.14, 59.39,172.85, 59.12,182.46,
     $  58.80,191.82, 58.48,200.82, 58.22,209.37, 58.12,217.46,
     $  58.27,225.14, 58.72,232.55, 59.51,239.83, 60.63,247.17,
     $  62.08,254.73, 63.80,262.73, 65.75,271.42, 67.82,281.13,
     $  69.91,292.35, 71.82,305.51, 73.30,320.94, 74.10,338.03,
     $  74.08,355.73, 73.26, 12.54, 71.81, 27.45, 70.01, 39.99,
     $  68.10, 50.67, 66.26, 60.01, 64.61, 68.47, 63.25, 76.45/
C
      DATA((A(I,J, 14),I=1,2),J=1,36)/
     $  60.01, 83.06, 59.23, 90.95, 58.71, 99.03, 58.37,107.37,
     $  58.16,116.01, 58.03,124.93, 57.95,134.13, 57.88,143.57,
     $  57.78,153.22, 57.65,163.01, 57.44,172.85, 57.15,182.60,
     $  56.80,192.11, 56.44,201.25, 56.14,209.91, 56.01,218.10,
     $  56.13,225.88, 56.57,233.38, 57.37,240.76, 58.52,248.20,
     $  60.00,255.87, 61.77,263.99, 63.75,272.77, 65.88,282.56,
     $  68.00,293.72, 69.95,306.73, 71.46,321.76, 72.28,338.45,
     $  72.25,355.68, 71.39, 12.02, 69.89, 26.47, 68.03, 38.86,
     $  66.03, 49.48, 64.13, 58.77, 62.45, 67.22, 61.07, 75.22/
C
      DATA((A(I,J, 15),I=1,2),J=1,36)/
     $  57.81, 82.00, 57.07, 89.97, 56.58, 98.14, 56.29,106.60,
     $  56.13,115.35, 56.03,124.40, 55.97,133.72, 55.90,143.27,
     $  55.81,153.01, 55.68,162.90, 55.47,172.84, 55.17,182.71,
     $  54.79,192.34, 54.40,201.60, 54.06,210.37, 53.89,218.64,
     $  53.99,226.50, 54.43,234.08, 55.24,241.56, 56.42,249.09,
     $  57.92,256.88, 59.73,265.10, 61.75,273.97, 63.91,283.79,
     $  66.07,294.92, 68.05,307.76, 69.58,322.49, 70.41,338.75,
     $  70.38,355.52, 69.50, 11.46, 67.96, 25.67, 66.01, 37.94,
     $  63.94, 48.45, 61.98, 57.69, 60.26, 66.12, 58.86, 74.12/
C
      DATA((A(I,J, 16),I=1,2),J=1,36)/
     $  55.56, 81.06, 54.87, 89.08, 54.44, 97.35, 54.20,105.91,
     $  54.08,114.79, 54.02,123.96, 53.97,133.38, 53.91,143.02,
     $  53.82,152.84, 53.68,162.80, 53.47,172.82, 53.16,182.79,
     $  52.77,192.52, 52.34,201.88, 51.97,210.74, 51.78,219.09,
     $  51.87,227.03, 52.31,234.69, 53.14,242.25, 54.33,249.89,
     $  55.87,257.78, 57.69,266.09, 59.74,275.04, 61.93,284.89,
     $  64.12,295.98, 66.12,308.66, 67.69,323.11, 68.54,339.00,
     $  68.51,355.37, 67.60, 11.00, 65.99, 25.02, 63.97, 37.13,
     $  61.82, 47.56, 59.78, 56.75, 58.01, 65.14, 56.60, 73.15/
C
      DATA((A(I,J, 17),I=1,2),J=1,36)/
     $  53.28, 80.21, 52.63, 88.29, 52.27, 96.64, 52.09,105.31,
     $  52.03,114.30, 51.99,123.58, 51.96,133.10, 51.90,142.82,
     $  51.81,152.71, 51.67,162.72, 51.46,172.80, 51.14,182.83,
     $  50.73,192.66, 50.28,202.10, 49.88,211.04, 49.67,219.47,
     $  49.75,227.47, 50.20,235.20, 51.05,242.86, 52.27,250.61,
     $  53.83,258.60, 55.66,267.01, 57.72,276.02, 59.93,285.89,
     $  62.15,296.92, 64.18,309.45, 65.77,323.65, 66.65,339.21,
     $  66.62,355.25, 65.68, 10.62, 64.01, 24.44, 61.91, 36.42,
     $  59.67, 46.78, 57.54, 55.91, 55.72, 64.28, 54.29, 72.28/
C
      DATA((A(I,J, 18),I=1,2),J=1,36)/
     $  50.94, 79.44, 50.35, 87.57, 50.06, 96.00, 49.96,104.77,
     $  49.95,113.87, 49.96,123.26, 49.93,132.88, 49.87,142.67,
     $  49.77,152.60, 49.63,162.64, 49.42,172.76, 49.11,182.85,
     $  48.69,192.75, 48.21,202.26, 47.79,211.27, 47.56,219.77,
     $  47.64,227.84, 48.11,235.65, 48.98,243.40, 50.24,251.24,
     $  51.81,259.35, 53.65,267.86, 55.72,276.93, 57.93,286.80,
     $  60.16,297.77, 62.22,310.16, 63.84,324.12, 64.73,339.38,
     $  64.71,355.13, 63.75, 10.26, 62.02, 23.92, 59.83, 35.81,
     $  57.48, 46.10, 55.26, 55.18, 53.38, 63.51, 51.93, 71.49/
C
      DATA((A(I,J, 19),I=1,2),J=1,36)/
     $  48.56, 78.74, 48.04, 86.92, 47.84, 95.42, 47.82,104.29,
     $  47.87,113.50, 47.91,123.00, 47.90,132.71, 47.83,142.55,
     $  47.72,152.51, 47.58,162.58, 47.37,172.72, 47.06,182.85,
     $  46.63,192.80, 46.14,202.38, 45.70,211.46, 45.46,220.01,
     $  45.55,228.14, 46.04,236.04, 46.94,243.87, 48.22,251.83,
     $  49.81,260.05, 51.66,268.64, 53.72,277.77, 55.92,287.65,
     $  58.15,298.56, 60.24,310.80, 61.89,324.53, 62.81,339.52,
     $  62.79,355.01, 61.81,  9.93, 60.02, 23.46, 57.73, 35.28,
     $  55.26, 45.50, 52.94, 54.53, 50.98, 62.82, 49.52, 70.78/
C
      DATA((A(I,J, 20),I=1,2),J=1,36)/
     $  46.13, 78.10, 45.68, 86.32, 45.57, 94.89, 45.65,103.86,
     $  45.77,113.18, 45.85,122.78, 45.85,132.57, 45.77,142.47,
     $  45.65,152.45, 45.50,162.52, 45.30,172.67, 44.99,182.82,
     $  44.57,192.82, 44.07,202.46, 43.62,211.59, 43.37,220.20,
     $  43.47,228.40, 43.99,236.37, 44.93,244.30, 46.23,252.37,
     $  47.83,260.70, 49.68,269.39, 51.73,278.58, 53.91,288.45,
     $  56.15,299.29, 58.24,311.38, 59.92,324.89, 60.87,339.64,
     $  60.87,354.88, 59.86,  9.63, 58.01, 23.06, 55.60, 34.80,
     $  53.01, 44.97, 50.57, 53.95, 48.53, 62.19, 47.04, 70.13/
C
      DATA((A(I,J, 21),I=1,2),J=1,36)/
     $  43.63, 77.52, 43.28, 85.78, 43.28, 94.42, 43.45,103.47,
     $  43.66,112.89, 43.79,122.60, 43.80,132.48, 43.70,142.42,
     $  43.56,152.41, 43.41,162.47, 43.21,172.61, 42.92,182.78,
     $  42.50,192.81, 42.00,202.50, 41.54,211.68, 41.29,220.34,
     $  41.41,228.60, 41.96,236.65, 42.94,244.69, 44.26,252.88,
     $  45.87,261.31, 47.71,270.10, 49.74,279.34, 51.91,289.21,
     $  54.13,299.97, 56.23,311.92, 57.93,325.22, 58.92,339.72,
     $  58.93,354.75, 57.91,  9.35, 55.98, 22.69, 53.46, 34.38,
     $  50.73, 44.50, 48.14, 53.42, 46.01, 61.62, 44.51, 69.54/
C
      DATA((A(I,J, 22),I=1,2),J=1,36)/
     $  41.09, 76.99, 40.83, 85.29, 40.95, 94.00, 41.24,103.13,
     $  41.53,112.65, 41.71,122.45, 41.73,132.40, 41.62,142.39,
     $  41.46,152.38, 41.30,162.42, 41.11,172.55, 40.84,182.72,
     $  40.43,192.78, 39.93,202.50, 39.46,211.73, 39.22,220.45,
     $  39.36,228.77, 39.96,236.90, 40.97,245.05, 42.33,253.35,
     $  43.94,261.90, 45.76,270.78, 47.76,280.07, 49.90,289.94,
     $  52.11,300.62, 54.21,312.41, 55.94,325.51, 56.95,339.78,
     $  56.99,354.62, 55.95,  9.09, 53.95, 22.35, 51.31, 33.99,
     $  48.41, 44.07, 45.67, 52.95, 43.44, 61.10, 41.91, 69.00/
C
      DATA((A(I,J, 23),I=1,2),J=1,36)/
     $  38.47, 76.50, 38.33, 84.84, 38.59, 93.61, 39.00,102.83,
     $  39.39,112.45, 39.63,122.34, 39.66,132.36, 39.53,142.38,
     $  39.35,152.36, 39.18,162.38, 39.00,172.48, 38.75,182.65,
     $  38.36,192.72, 37.85,202.48, 37.39,211.75, 37.16,220.52,
     $  37.34,228.91, 37.98,237.12, 39.04,245.37, 40.42,253.79,
     $  42.03,262.46, 43.82,271.43, 45.79,280.77, 47.89,290.63,
     $  50.08,301.24, 52.18,312.89, 53.93,325.78, 54.99,339.84,
     $  55.05,354.49, 53.99,  8.84, 51.92, 22.04, 49.13, 33.65,
     $  46.06, 43.69, 43.15, 52.52, 40.80, 60.63, 39.24, 68.50/
C
      DATA((A(I,J, 24),I=1,2),J=1,36)/
     $  35.78, 76.05, 35.77, 84.43, 36.18, 93.27, 36.74,102.57,
     $  37.24,112.27, 37.53,122.24, 37.57,132.33, 37.43,142.38,
     $  37.22,152.36, 37.04,162.34, 36.88,172.42, 36.65,182.57,
     $  36.27,192.65, 35.78,202.43, 35.32,211.74, 35.11,220.56,
     $  35.33,229.01, 36.02,237.32, 37.13,245.68, 38.54,254.22,
     $  40.14,263.00, 41.90,272.06, 43.82,281.45, 45.89,291.30,
     $  48.04,301.84, 50.14,313.34, 51.92,326.03, 53.02,339.87,
     $  53.11,354.35, 52.04,  8.60, 49.88, 21.74, 46.95, 33.33,
     $  43.67, 43.34, 40.56, 52.12, 38.07, 60.19, 36.48, 68.04/
C
      DATA((A(I,J, 25),I=1,2),J=1,36)/
     $  33.01, 75.64, 33.16, 84.07, 33.73, 92.97, 34.44,102.34,
     $  35.06,112.11, 35.43,122.17, 35.48,132.31, 35.32,142.39,
     $  35.08,152.36, 34.89,162.31, 34.75,172.35, 34.54,182.48,
     $  34.19,192.56, 33.71,202.37, 33.25,211.71, 33.07,220.58,
     $  33.33,229.10, 34.09,237.49, 35.25,245.96, 36.68,254.62,
     $  38.27,263.52, 40.00,272.67, 41.87,282.10, 43.88,291.94,
     $  46.00,302.41, 48.09,313.76, 49.90,326.26, 51.04,339.90,
     $  51.16,354.21, 50.08,  8.35, 47.85, 21.46, 44.76, 33.03,
     $  41.25, 43.01, 37.91, 51.76, 35.26, 59.78, 33.63, 67.61/
C
      DATA((A(I,J, 26),I=1,2),J=1,36)/
     $  30.16, 75.27, 30.47, 83.75, 31.23, 92.70, 32.12,102.13,
     $  32.87,111.98, 33.31,122.11, 33.38,132.31, 33.19,142.40,
     $  32.93,152.36, 32.73,162.28, 32.60,172.28, 32.43,182.39,
     $  32.10,192.47, 31.63,202.29, 31.19,211.66, 31.03,220.58,
     $  31.35,229.17, 32.17,237.66, 33.39,246.24, 34.84,255.02,
     $  36.42,264.03, 38.11,273.26, 39.92,282.74, 41.88,292.57,
     $  43.96,302.96, 46.04,314.18, 47.87,326.48, 49.05,339.92,
     $  49.22,354.06, 48.13,  8.11, 45.82, 21.19, 42.55, 32.74,
     $  38.80, 42.71, 35.19, 51.42, 32.35, 59.41, 30.67, 67.22/
C
      DATA((A(I,J, 27),I=1,2),J=1,36)/
     $  27.19, 74.93, 27.70, 83.46, 28.68, 92.48, 29.76,101.96,
     $  30.66,111.88, 31.18,122.06, 31.27,132.31, 31.06,142.43,
     $  30.77,152.37, 30.56,162.25, 30.45,172.21, 30.31,182.29,
     $  30.01,192.36, 29.56,202.19, 29.13,211.60, 29.00,220.57,
     $  29.38,229.22, 30.27,237.81, 31.54,246.51, 33.02,255.41,
     $  34.59,264.53, 36.23,273.84, 37.98,283.36, 39.88,293.18,
     $  41.91,303.49, 43.99,314.58, 45.83,326.70, 47.06,339.92,
     $  47.27,353.90, 46.19,  7.86, 43.80, 20.91, 40.34, 32.47,
     $  36.31, 42.43, 32.39, 51.11, 29.31, 59.06, 27.59, 66.86/
C
      DATA((A(I,J, 28),I=1,2),J=1,36)/
     $  24.08, 74.63, 24.84, 83.21, 26.07, 92.28, 27.36,101.82,
     $  28.42,111.79, 29.03,122.03, 29.15,132.32, 28.92,142.45,
     $  28.60,152.37, 28.38,162.22, 28.29,172.15, 28.18,182.20,
     $  27.91,192.25, 27.48,202.09, 27.08,211.53, 26.98,220.55,
     $  27.42,229.28, 28.39,237.95, 29.72,246.77, 31.22,255.79,
     $  32.77,265.01, 34.36,274.40, 36.05,283.96, 37.88,293.77,
     $  39.87,304.02, 41.92,314.97, 43.78,326.91, 45.06,339.93,
     $  45.33,353.74, 44.26,  7.61, 41.78, 20.64, 38.13, 32.20,
     $  33.79, 42.15, 29.49, 50.81, 26.14, 58.73, 24.34, 66.53/
C
      DATA((A(I,J, 29),I=1,2),J=1,36)/
     $  20.80, 74.37, 21.85, 82.99, 23.38, 92.11, 24.93,101.70,
     $  26.17,111.71, 26.88,122.01, 27.02,132.33, 26.76,142.46,
     $  26.41,152.37, 26.19,162.19, 26.12,172.08, 26.04,182.10,
     $  25.81,192.14, 25.41,201.99, 25.02,211.46, 24.97,220.52,
     $  25.47,229.33, 26.52,238.10, 27.91,247.03, 29.43,256.17,
     $  30.95,265.49, 32.49,274.95, 34.11,284.54, 35.88,294.35,
     $  37.81,304.53, 39.84,315.35, 41.73,327.10, 43.06,339.93,
     $  43.38,353.57, 42.33,  7.35, 39.77, 20.36, 35.91, 31.93,
     $  31.22, 41.89, 26.50, 50.52, 22.77, 58.43, 20.87, 66.23/
C
      DATA((A(I,J, 30),I=1,2),J=1,36)/
     $  17.24, 74.13, 18.71, 82.81, 20.60, 91.97, 22.44,101.60,
     $  23.89,111.66, 24.72,121.99, 24.88,132.34, 24.60,142.48,
     $  24.22,152.37, 24.00,162.17, 23.94,172.02, 23.90,182.01,
     $  23.70,192.03, 23.33,201.88, 22.97,211.38, 22.95,220.50,
     $  23.52,229.38, 24.65,238.25, 26.11,247.29, 27.65,256.54,
     $  29.14,265.96, 30.62,275.48, 32.17,285.11, 33.87,294.90,
     $  35.76,305.02, 37.76,315.72, 39.67,327.30, 41.06,339.92,
     $  41.44,353.40, 40.40,  7.08, 37.77, 20.07, 33.69, 31.65,
     $  28.60, 41.62, 23.36, 50.25, 19.14, 58.14, 17.07, 65.95/
C
      DATA((A(I,J, 31),I=1,2),J=1,36)/
     $  13.22, 73.92, 15.30, 82.65, 17.70, 91.86, 19.90,101.53,
     $  21.59,111.62, 22.54,121.98, 22.73,132.34, 22.43,142.48,
     $  22.03,152.37, 21.79,162.14, 21.76,171.97, 21.75,181.93,
     $  21.59,191.93, 21.25,201.78, 20.92,211.31, 20.94,220.48,
     $  21.58,229.44, 22.80,238.41, 24.32,247.55, 25.87,256.90,
     $  27.34,266.41, 28.75,276.00, 30.23,285.65, 31.86,295.44,
     $  33.69,305.50, 35.68,316.09, 37.60,327.50, 39.05,339.92,
     $  39.50,353.23, 38.49,  6.81, 35.78, 19.77, 31.47, 31.37,
     $  25.95, 41.35, 20.04, 49.97, 15.07, 57.86, 12.66, 65.70/
C
      DATA((A(I,J, 32),I=1,2),J=1,36)/
     $   8.12, 73.73, 11.44, 82.53, 14.62, 91.78, 17.30,101.48,
     $  19.27,111.59, 20.35,121.98, 20.57,132.35, 20.25,142.48,
     $  19.82,152.36, 19.58,162.11, 19.56,171.92, 19.59,181.85,
     $  19.47,191.83, 19.16,201.68, 18.86,211.24, 18.93,220.48,
     $  19.64,229.52, 20.95,238.58, 22.53,247.82, 24.09,257.27,
     $  25.53,266.86, 26.88,276.50, 28.28,286.18, 29.84,295.96,
     $  31.62,305.97, 33.58,316.45, 35.52,327.69, 37.03,339.92,
     $  37.56,353.05, 36.58,  6.53, 33.81, 19.46, 29.25, 31.07,
     $  23.24, 41.06, 16.44, 49.70, 10.05, 57.59,  6.54, 65.46/
C
      DATA((A(I,J, 33),I=1,2),J=1,36)/
     $   7.18, 73.56,  6.33, 82.42, 11.22, 91.72, 14.59,101.45,
     $  16.91,111.58, 18.14,121.97, 18.41,132.34, 18.07,142.47,
     $  17.61,152.34, 17.36,162.09, 17.36,171.87, 17.42,181.78,
     $  17.34,191.73, 17.07,201.58, 16.81,211.18, 16.92,220.48,
     $  17.71,229.60, 19.09,238.75, 20.74,248.09, 22.31,257.63,
     $  23.71,267.29, 25.00,276.98, 26.33,286.68, 27.83,296.45,
     $  29.55,306.42, 31.48,316.80, 33.44,327.88, 35.01,339.92,
     $  35.61,352.88, 34.68,  6.24, 31.85, 19.13, 27.04, 30.75,
     $  20.45, 40.77, 12.34, 49.41,  6.28, 57.26,  5.86, 65.18/
C
      DATA((A(I,J, 34),I=1,2),J=1,36)/
     $   5.29, 73.39,  5.52, 82.34,  7.05, 91.68, 11.72,101.43,
     $  14.51,111.59, 15.92,121.98, 16.23,132.34, 15.88,142.45,
     $  15.39,152.32, 15.13,162.06, 15.14,171.84, 15.24,181.72,
     $  15.20,191.65, 14.97,201.50, 14.75,211.13, 14.91,220.50,
     $  15.77,229.71, 17.24,238.95, 18.94,248.37, 20.52,257.99,
     $  21.88,267.71, 23.11,277.44, 24.38,287.16, 25.81,296.93,
     $  27.47,306.86, 29.38,317.14, 31.35,328.07, 32.99,339.93,
     $  33.67,352.71, 32.79,  5.95, 29.90, 18.79, 24.84, 30.41,
     $  17.58, 40.45,  6.91, 49.12,  5.62, 56.85,  5.17, 64.89/
C
      DATA((A(I,J, 35),I=1,2),J=1,36)/
     $   3.80, 73.22,  3.89, 82.26,  6.35, 91.66,  8.57,101.44,
     $  12.06,111.60, 13.69,121.98, 14.05,132.33, 13.67,142.43,
     $  13.16,152.28, 12.89,162.03, 12.92,171.80, 13.03,181.66,
     $  13.04,191.57, 12.86,201.42, 12.68,211.09, 12.90,220.53,
     $  13.82,229.83, 15.37,239.16, 17.13,248.66, 18.72,258.35,
     $  20.04,268.12, 21.21,277.89, 22.41,287.62, 23.78,297.39,
     $  25.40,307.28, 27.27,317.48, 29.26,328.27, 30.96,339.94,
     $  31.72,352.54, 30.90,  5.65, 27.96, 18.43, 22.65, 30.04,
     $  14.56, 40.10,  6.22, 48.58,  3.51, 56.44,  2.41, 64.61/
C
      DATA((A(I,J, 36),I=1,2),J=1,36)/
     $   2.66, 73.05,  2.30, 82.18,  4.55, 91.65,  7.13,101.45,
     $   9.51,111.62, 11.44,121.99, 11.85,132.31, 11.47,142.39,
     $  10.93,152.24, 10.64,162.00, 10.67,171.77, 10.81,181.62,
     $  10.86,191.51, 10.73,201.36, 10.61,211.06, 10.88,220.58,
     $  11.87,229.96, 13.50,239.38, 15.30,248.95, 16.90,258.70,
     $  18.18,268.52, 19.30,278.31, 20.44,288.06, 21.75,297.83,
     $  23.32,307.69, 25.17,317.82, 27.17,328.48, 28.92,339.97,
     $  29.78,352.38, 29.01,  5.34, 26.04, 18.04, 20.47, 29.64,
     $  11.26, 39.73,  5.53, 48.04,  2.01, 56.04,  1.32, 64.33/
C
      DATA((A(I,J, 37),I=1,2),J=1,36)/
     $   1.79, 72.88,  1.01, 82.10,  3.00, 91.64,  5.29,101.49,
     $   6.79,111.66,  9.17,122.00,  9.65,132.28,  9.25,142.34,
     $   8.69,152.20,  8.38,161.97,  8.39,171.75,  8.54,181.59,
     $   8.63,191.46,  8.58,201.31,  8.53,211.05,  8.86,220.64,
     $   9.92,230.12, 11.61,239.62, 13.45,249.26, 15.06,259.05,
     $  16.31,268.90, 17.37,278.71, 18.46,288.48, 19.72,298.24,
     $  21.24,308.09, 23.06,318.15, 25.07,328.68, 26.89,340.00,
     $  27.82,352.23, 27.12,  5.03, 24.14, 17.64, 18.30, 29.21,
     $   7.37, 39.32,  3.26, 47.50,  0.86, 55.63,  0.60, 64.04/
C
      DATA((A(I,J, 38),I=1,2),J=1,36)/
     $   1.12, 72.71, -0.06, 82.03,  1.64, 91.63,  3.60,101.52,
     $   5.25,111.70,  6.86,122.02,  7.44,132.25,  7.03,142.28,
     $   6.43,152.14,  6.08,161.93,  6.05,171.73,  6.19,181.56,
     $   6.34,191.42,  6.39,201.27,  6.43,211.06,  6.83,220.73,
     $   7.95,230.30,  9.70,239.87, 11.59,249.56, 13.19,259.39,
     $  14.42,269.26, 15.43,279.09, 16.47,288.87, 17.68,298.64,
     $  19.15,308.47, 20.95,318.47, 22.97,328.90, 24.84,340.05,
     $  25.87,352.09, 25.24,  4.72, 22.24, 17.22, 16.14, 28.75,
     $   6.79, 38.76,  1.97, 46.97,  0.01, 55.22,  0.16, 63.76/
C
      DATA((A(I,J, 39),I=1,2),J=1,36)/
     $   0.57, 72.54, -0.96, 81.95,  0.41, 91.62,  2.02,101.55,
     $   3.37,111.72,  4.79,122.02,  5.23,132.20,  4.79,142.21,
     $   4.24,152.08,  3.96,161.90,  4.05,171.72,  4.32,181.55,
     $   4.49,191.40,  4.43,201.25,  4.39,211.08,  4.80,220.83,
     $   5.97,230.49,  7.77,240.14,  9.69,249.88, 11.30,259.73,
     $  12.50,269.62, 13.47,279.46, 14.47,289.25, 15.64,299.02,
     $  17.07,308.84, 18.84,318.79, 20.87,329.12, 22.80,340.11,
     $  23.91,351.96, 23.35,  4.41, 20.36, 16.78, 13.98, 28.25,
     $   5.05, 38.10,  0.93, 46.43, -0.62, 54.82, -0.08, 63.48/
C
      DATA((A(I,J, 40),I=1,2),J=1,36)/
     $   0.09, 72.37, -1.77, 81.87, -0.74, 91.61,  0.50,101.58,
     $   1.56,111.75,  2.65,122.03,  2.98,132.15,  2.57,142.12,
     $   2.03,152.00,  1.79,161.86,  1.95,171.71,  2.30,181.55,
     $   2.50,191.40,  2.42,201.24,  2.35,211.12,  2.78,220.95,
     $   3.98,230.70,  5.82,240.42,  7.76,250.19,  9.38,260.06,
     $  10.56,269.96, 11.50,279.81, 12.45,289.61, 13.59,299.39,
     $  14.99,309.19, 16.73,319.11, 18.78,329.34, 20.75,340.19,
     $  21.94,351.84, 21.47,  4.10, 18.49, 16.32, 11.82, 27.72,
     $   3.56, 37.43,  0.08, 45.89, -1.08, 54.41, -0.21, 63.19/
C
      DATA((A(I,J, 41),I=1,2),J=1,36)/
     $  -0.40, 72.20, -2.55, 81.79, -1.87, 91.60, -1.01,101.62,
     $  -0.22,111.77,  0.52,121.99,  0.75,132.09,  0.35,142.01,
     $  -0.17,151.89, -0.37,161.79, -0.14,171.69,  0.30,181.56,
     $   0.53,191.42,  0.41,201.28,  0.31,211.19,  0.74,221.09,
     $   1.98,230.93,  3.84,240.71,  5.79,250.52,  7.43,260.39,
     $   8.60,270.29,  9.50,280.15, 10.43,289.95, 11.54,299.74,
     $  12.90,309.54, 14.62,319.43, 16.68,329.58, 18.71,340.28,
     $  19.97,351.74, 19.57,  3.80, 16.64, 15.85,  9.63, 27.15,
     $   2.29, 36.77, -0.61, 45.35, -1.45, 54.00, -0.32, 62.91/
C
      DATA((A(I,J, 42),I=1,2),J=1,36)/
     $  -0.97, 72.03, -3.35, 81.71, -3.04, 91.59, -2.56,101.65,
     $  -2.02,111.80, -1.61,121.95, -1.47,132.01, -1.87,141.92,
     $  -2.37,151.82, -2.54,161.76, -2.23,171.67, -1.71,181.57,
     $  -1.44,191.44, -1.60,201.32, -1.74,211.24, -1.30,221.24,
     $  -0.02,231.18,  1.88,241.02,  3.85,250.84,  5.43,260.71,
     $   6.62,270.61,  7.50,280.47,  8.39,290.29,  9.47,300.08,
     $  10.81,309.88, 12.52,319.74, 14.59,329.82, 16.66,340.39,
     $  17.99,351.66, 17.67,  3.50, 14.78, 15.36,  7.36, 26.55,
     $   1.17, 36.10, -1.21, 44.81, -1.78, 53.60, -0.48, 62.63/
C
      DATA((A(I,J, 43),I=1,2),J=1,36)/
     $  -1.68, 71.86, -4.26, 81.63, -4.31, 91.58, -4.18,101.68,
     $  -3.88,111.83, -3.75,121.98, -3.69,131.91, -4.09,141.79,
     $  -4.57,151.71, -4.70,161.70, -4.33,171.68, -3.74,181.57,
     $  -3.45,191.41, -3.63,201.31, -3.80,211.33, -3.34,221.40,
     $  -2.04,231.42, -0.10,241.34,  1.88,251.17,  3.46,261.04,
     $   4.58,270.93,  5.47,280.79,  6.34,290.62,  7.39,300.42,
     $   8.71,310.22, 10.41,320.05, 12.50,330.07, 14.61,340.52,
     $  16.00,351.60, 15.76,  3.21, 12.94, 14.87,  6.11, 25.92,
     $   0.18, 35.44, -1.77, 44.27, -2.14, 53.19, -0.79, 62.34/
C
      DATA((A(I,J, 44),I=1,2),J=1,36)/
     $  -2.62, 71.69, -5.33, 81.55, -5.74, 91.58, -5.93,101.76,
     $  -5.16,111.91, -5.76,121.93, -5.88,131.80, -6.27,141.64,
     $  -6.74,151.59, -6.79,161.63, -6.28,171.66, -5.54,181.58,
     $  -5.20,191.44, -5.49,201.36, -5.78,211.43, -5.38,221.58,
     $  -4.06,231.69, -2.10,241.65, -0.10,251.51,  1.45,261.36,
     $   2.55,271.24,  3.42,281.11,  4.36,290.94,  5.27,300.75,
     $   6.59,310.55,  8.30,320.37, 10.42,330.33, 12.57,340.66,
     $  14.01,351.55, 13.84,  2.93, 11.10, 14.36,  4.51, 25.25,
     $  -0.73, 34.78, -2.33, 43.74, -2.59, 52.78, -1.33, 62.06/
C
      DATA((A(I,J, 45),I=1,2),J=1,36)/
     $  -3.84, 71.52, -6.62, 81.47, -7.38, 91.59, -6.94,101.77,
     $  -8.03,111.90, -8.10,121.86, -8.11,131.66, -8.51,141.48,
     $  -8.99,151.45, -9.08,161.55, -8.64,171.63, -7.98,181.60,
     $  -7.63,191.48, -7.77,201.43, -7.93,211.54, -7.46,221.78,
     $  -6.08,231.96, -4.12,241.97, -2.11,251.84, -0.57,261.68,
     $   0.50,271.55,  1.39,281.42,  2.37,291.26,  3.38,301.07,
     $   4.63,310.87,  6.18,320.68,  8.35,330.60, 10.53,340.82,
     $  12.01,351.53, 11.91,  2.67,  9.26, 13.86,  2.99, 24.57,
     $  -1.60, 34.11, -2.96, 43.20, -3.20, 52.38, -2.18, 61.78/
C
      DATA((A(I,J, 46),I=1,2),J=1,36)/
     $  -5.41, 71.35, -8.22, 81.39, -8.43, 91.53,-10.17,101.75,
     $ -10.58,111.87,-10.39,121.76,-10.34,131.49,-10.74,141.29,
     $ -11.24,151.29,-11.35,161.45,-10.94,171.60,-10.33,181.61,
     $  -9.96,191.53,-10.01,201.51,-10.07,211.67, -9.55,221.98,
     $  -8.15,232.24, -6.09,242.31, -4.14,252.19, -2.62,262.01,
     $  -1.56,271.87, -0.65,281.74,  0.39,291.59,  1.44,301.41,
     $   2.66,311.20,  4.21,321.00,  6.28,330.87,  8.50,341.00,
     $   9.99,351.53,  9.96,  2.42,  7.42, 13.35,  1.54, 23.89,
     $  -2.47, 33.45, -3.70, 42.66, -4.03, 51.97, -3.43, 61.49/
C
      DATA((A(I,J, 47),I=1,2),J=1,36)/
     $  -5.20, 71.18, -9.63, 81.21,-11.96, 91.44,-12.95,101.70,
     $ -12.98,111.79,-12.64,121.62,-12.57,131.30,-12.97,141.07,
     $ -13.47,151.11,-13.60,161.33,-13.23,171.55,-12.64,181.62,
     $ -12.25,191.58,-12.22,201.59,-12.20,211.81,-11.64,222.20,
     $ -10.24,232.53, -8.20,242.65, -6.12,252.54, -4.69,262.35,
     $  -3.63,272.20, -2.68,282.07, -1.58,291.92, -0.48,301.75,
     $   0.72,311.55,  2.24,321.33,  4.25,331.16,  6.47,341.19,
     $   7.97,351.54,  7.99,  2.18,  5.59, 12.86,  0.12, 23.21,
     $  -3.40, 32.78, -4.60, 42.12, -5.14, 51.56, -5.44, 61.21/
C
      DATA((A(I,J, 48),I=1,2),J=1,36)/
     $ -10.62, 70.84,-13.33, 80.99,-14.94, 91.31,-15.51,101.61,
     $ -15.31,111.68,-14.87,121.44,-14.78,131.06,-15.19,140.83,
     $ -15.69,150.90,-15.84,161.19,-15.50,171.49,-14.93,181.63,
     $ -14.53,191.63,-14.44,201.69,-14.34,211.97,-13.73,222.42,
     $ -12.33,232.83,-10.32,242.99, -8.28,252.89, -6.74,262.70,
     $  -5.67,272.54, -4.72,282.41, -3.56,292.27, -2.40,302.09,
     $  -1.20,311.88,  0.30,321.68,  2.24,331.46,  4.46,341.40,
     $   5.91,351.57,  5.99,  1.97,  3.71, 12.37, -1.28, 22.52,
     $  -4.41, 32.12, -5.72, 41.58, -6.61, 51.16, -6.44, 60.93/
C
      DATA((A(I,J, 49),I=1,2),J=1,36)/
     $ -14.34, 70.45,-16.43, 80.73,-17.62, 91.14,-17.93,101.48,
     $ -17.57,111.53,-17.07,121.22,-16.99,130.79,-17.40,140.55,
     $ -17.91,150.66,-18.07,161.03,-17.76,171.41,-17.22,181.62,
     $ -16.80,191.69,-16.65,201.80,-16.49,212.14,-15.84,222.66,
     $ -14.43,233.14,-12.46,243.34,-10.44,253.26, -8.89,263.06,
     $  -7.78,272.89, -6.71,282.77, -5.44,292.62, -4.32,302.44,
     $  -3.11,312.23, -1.62,322.01,  0.26,331.80,  2.46,341.62,
     $   4.05,351.63,  4.16,  1.76,  1.87, 11.90, -2.69, 21.84,
     $  -5.55, 31.45, -7.11, 41.04, -7.56, 50.62,-11.39, 60.41/
C
      DATA((A(I,J, 50),I=1,2),J=1,36)/
     $ -17.41, 70.03,-19.18, 80.43,-20.12, 90.93,-20.24,101.30,
     $ -19.78,111.31,-19.26,120.96,-19.18,130.48,-19.60,140.23,
     $ -20.12,150.38,-20.30,160.83,-20.02,171.31,-19.50,181.60,
     $ -19.07,191.74,-18.86,201.92,-18.64,212.32,-17.95,222.91,
     $ -16.55,233.45,-14.60,243.70,-12.62,253.64,-11.05,263.44,
     $  -9.88,273.27, -8.78,283.14, -7.52,293.00, -6.13,302.81,
     $  -5.01,312.59, -3.53,322.35, -1.72,332.10,  0.48,341.91,
     $   2.15,351.70,  2.28,  1.58,  0.03, 11.46, -4.13, 21.16,
     $  -6.87, 30.73, -8.27, 40.26,-11.81, 49.94,-14.93, 59.85/
C
      DATA((A(I,J, 51),I=1,2),J=1,36)/
     $ -20.14, 69.56,-21.70, 80.08,-22.47, 90.66,-22.46,101.05,
     $ -21.93,111.04,-21.42,120.63,-21.36,130.12,-21.78,139.87,
     $ -22.31,150.07,-22.52,160.61,-22.28,171.18,-21.78,181.57,
     $ -21.34,191.79,-21.08,202.04,-20.80,212.51,-20.07,223.17,
     $ -18.68,233.77,-16.76,244.07,-14.80,254.03,-13.21,263.84,
     $ -12.00,273.66,-10.85,283.54, -9.57,293.40, -8.19,303.20,
     $  -6.78,312.97, -5.28,322.72, -3.67,332.44, -1.49,342.12,
     $   0.26,351.86,  0.42,  1.51, -1.81, 11.00, -5.63, 20.50,
     $  -8.15, 29.95,-11.64, 39.48,-14.98, 49.23,-17.87, 59.26/
C
      DATA((A(I,J, 52),I=1,2),J=1,36)/
     $ -22.61, 69.06,-24.04, 79.68,-24.69, 90.33,-24.60,100.74,
     $ -24.05,110.70,-23.55,120.25,-23.52,129.71,-23.96,139.47,
     $ -24.50,149.73,-24.74,160.35,-24.53,171.02,-24.05,181.52,
     $ -23.61,191.84,-23.31,202.17,-22.96,212.72,-22.20,223.44,
     $ -20.81,234.11,-18.92,244.45,-16.99,254.45,-15.38,264.26,
     $ -14.11,274.09,-12.91,283.96,-11.60,293.81,-10.21,303.61,
     $  -8.82,313.36, -7.32,323.10, -5.56,332.79, -3.44,342.39,
     $  -1.62,351.92, -1.44,  1.32, -3.64, 10.59, -7.09, 19.86,
     $ -10.72, 29.18,-14.34, 38.69,-17.65, 48.51,-20.45, 58.64/
C
      DATA((A(I,J, 53),I=1,2),J=1,36)/
     $ -24.87, 68.51,-26.23, 79.23,-26.81, 89.94,-26.67,100.36,
     $ -26.12,110.29,-25.65,119.80,-25.65,129.24,-26.12,139.02,
     $ -26.68,149.33,-26.94,160.04,-26.77,170.83,-26.33,181.44,
     $ -25.88,191.87,-25.54,202.31,-25.13,212.93,-24.34,223.73,
     $ -22.95,234.46,-21.10,244.85,-19.18,254.88,-17.56,264.71,
     $ -16.23,274.54,-14.97,284.41,-13.62,294.26,-12.22,304.04,
     $ -10.82,313.78, -9.31,323.51, -7.52,333.16, -5.36,342.68,
     $  -3.50,352.01, -3.30,  1.16, -5.45, 10.20, -9.09, 19.25,
     $ -12.94, 28.44,-16.67, 37.92,-20.02, 47.77,-22.78, 57.99/
C
      DATA((A(I,J, 54),I=1,2),J=1,36)/
     $ -26.97, 67.93,-28.29, 78.72,-28.83, 89.48,-28.67, 99.91,
     $ -28.14,109.81,-27.72,119.28,-27.77,128.71,-28.26,138.52,
     $ -28.84,148.90,-29.14,159.70,-29.02,170.61,-28.60,181.35,
     $ -28.15,191.90,-27.77,202.45,-27.32,213.16,-26.49,224.03,
     $ -25.10,234.82,-23.27,245.27,-21.38,255.33,-19.73,265.18,
     $ -18.34,275.02,-17.02,284.89,-15.63,294.73,-14.21,304.50,
     $ -12.79,314.22,-11.26,323.93, -9.45,333.55, -7.30,342.98,
     $  -5.26,352.15, -5.17,  1.07, -7.29,  9.85,-10.96, 18.67,
     $ -14.94, 27.73,-18.77, 37.16,-22.16, 47.04,-24.91, 57.32/
C
      DATA((A(I,J, 55),I=1,2),J=1,36)/
     $ -28.94, 67.31,-30.23, 78.17,-30.75, 88.96,-30.60, 99.38,
     $ -30.12,109.25,-29.76,118.70,-29.86,128.13,-30.38,137.96,
     $ -30.99,148.41,-31.33,159.31,-31.25,170.35,-30.88,181.23,
     $ -30.43,191.92,-30.01,202.59,-29.50,213.40,-28.64,224.35,
     $ -27.25,235.20,-25.45,245.70,-23.57,255.81,-21.90,265.69,
     $ -20.46,275.54,-19.07,285.40,-17.64,295.23,-16.18,304.98,
     $ -14.74,314.69,-13.19,324.38,-11.35,333.96, -9.22,343.30,
     $  -7.29,352.30, -6.95,  0.99, -9.13,  9.52,-12.77, 18.13,
     $ -16.82, 27.04,-20.71, 36.42,-24.11, 46.31,-26.88, 56.64/
C
      DATA((A(I,J, 56),I=1,2),J=1,36)/
     $ -30.77, 66.67,-32.06, 77.57,-32.58, 88.37,-32.46, 98.78,
     $ -32.04,108.61,-31.76,118.04,-31.91,127.48,-32.48,137.35,
     $ -33.13,147.86,-33.51,158.88,-33.48,170.04,-33.15,181.08,
     $ -32.70,191.92,-32.25,202.73,-31.70,213.65,-30.80,224.68,
     $ -29.41,235.60,-27.63,246.16,-25.76,256.32,-24.06,266.23,
     $ -22.56,276.09,-21.11,285.95,-19.63,295.76,-18.14,305.50,
     $ -16.67,315.19,-15.09,324.85,-13.24,334.39,-11.12,343.63,
     $  -9.27,352.47, -8.94,  0.94,-10.96,  9.23,-14.53, 17.63,
     $ -18.59, 26.40,-22.51, 35.72,-25.94, 45.59,-28.71, 55.95/
C
      DATA((A(I,J, 57),I=1,2),J=1,36)/
     $ -32.49, 66.00,-33.79, 76.92,-34.33, 87.72,-34.26, 98.09,
     $ -33.91,107.90,-33.71,117.31,-33.94,126.76,-34.55,136.68,
     $ -35.25,147.27,-35.68,158.39,-35.71,169.70,-35.41,180.90,
     $ -34.98,191.91,-34.50,202.87,-33.89,213.92,-32.96,225.04,
     $ -31.57,236.03,-29.81,246.65,-27.94,256.86,-26.22,266.80,
     $ -24.66,276.67,-23.15,286.53,-21.62,296.33,-20.09,306.05,
     $ -18.58,315.72,-16.98,325.35,-15.10,334.83,-13.00,343.98,
     $ -11.22,352.66,-10.90,  0.91,-12.79,  8.97,-16.26, 17.17,
     $ -20.29, 25.81,-24.21, 35.05,-27.65, 44.89,-30.43, 55.26/
C
      DATA((A(I,J, 58),I=1,2),J=1,36)/
     $ -34.12, 65.31,-35.43, 76.22,-36.00, 87.00,-35.99, 97.34,
     $ -35.73,107.11,-35.63,116.51,-35.93,125.98,-36.61,135.95,
     $ -37.35,146.62,-37.84,157.85,-37.92,169.31,-37.67,180.69,
     $ -37.25,191.88,-36.75,203.01,-36.10,214.19,-35.13,225.42,
     $ -33.73,236.48,-31.98,247.17,-30.12,257.43,-28.36,267.42,
     $ -26.74,277.30,-25.17,287.15,-23.59,296.94,-22.03,306.63,
     $ -20.48,316.28,-18.84,325.88,-16.95,335.30,-14.87,344.34,
     $ -13.15,352.86,-12.84,  0.91,-14.62,  8.75,-17.97, 16.76,
     $ -21.94, 25.26,-25.83, 34.41,-29.26, 44.22,-32.05, 54.57/
C
      DATA((A(I,J, 59),I=1,2),J=1,36)/
     $ -35.65, 64.61,-36.99, 75.49,-37.60, 86.23,-37.66, 96.51,
     $ -37.51,106.25,-37.50,115.64,-37.90,125.13,-38.63,135.15,
     $ -39.43,145.90,-39.98,157.26,-40.13,168.88,-39.93,180.44,
     $ -39.53,191.84,-39.00,203.15,-38.31,214.48,-37.30,225.82,
     $ -35.89,236.96,-34.15,247.72,-32.28,258.04,-30.49,268.07,
     $ -28.82,277.97,-27.19,287.82,-25.56,297.58,-23.96,307.25,
     $ -22.37,316.87,-20.69,326.43,-18.78,335.79,-16.72,344.72,
     $ -15.06,353.08,-14.76,  0.93,-16.43,  8.57,-19.66, 16.39,
     $ -23.54, 24.75,-27.38, 33.81,-30.79, 43.57,-33.57, 53.89/
C
      DATA((A(I,J, 60),I=1,2),J=1,36)/
     $ -37.11, 63.90,-38.46, 74.73,-39.13, 85.40,-39.27, 95.62,
     $ -39.23,105.31,-39.34,114.70,-39.82,124.22,-40.63,134.29,
     $ -41.49,145.13,-42.11,156.61,-42.33,168.39,-42.18,180.16,
     $ -41.80,191.77,-41.26,203.28,-40.53,214.78,-39.48,226.24,
     $ -38.05,237.48,-36.31,248.31,-34.44,258.70,-32.61,268.77,
     $ -30.88,278.68,-29.20,288.52,-27.52,298.26,-25.87,307.91,
     $ -24.24,317.50,-22.52,327.01,-20.59,336.30,-18.56,345.11,
     $ -16.96,353.31,-16.67,  0.97,-18.24,  8.42,-21.33, 16.08,
     $ -25.11, 24.30,-28.89, 33.26,-32.26, 42.95,-35.03, 53.23/
C
      DATA((A(I,J, 61),I=1,2),J=1,36)/
     $ -38.49, 63.18,-39.87, 73.94,-40.59, 84.52,-40.83, 94.66,
     $ -40.89,104.31,-41.12,113.69,-41.71,123.23,-42.60,133.36,
     $ -43.53,144.29,-44.22,155.89,-44.51,167.86,-44.43,179.84,
     $ -44.07,191.69,-43.51,203.42,-42.74,215.10,-41.66,226.70,
     $ -40.21,238.03,-38.46,248.94,-36.58,259.40,-34.72,269.51,
     $ -32.93,279.44,-31.19,289.27,-29.47,298.99,-27.78,308.61,
     $ -26.10,318.17,-24.34,327.63,-22.39,336.82,-20.39,345.52,
     $ -18.85,353.56,-18.56,  1.04,-20.05,  8.31,-22.99, 15.81,
     $ -26.65, 23.90,-30.34, 32.76,-33.67, 42.36,-36.41, 52.57/
C
      DATA((A(I,J, 62),I=1,2),J=1,36)/
     $ -39.81, 62.46,-41.21, 73.12,-41.99, 83.60,-42.32, 93.65,
     $ -42.52,103.24,-42.87,112.61,-43.57,122.18,-44.54,132.37,
     $ -45.55,143.38,-46.32,155.12,-46.69,167.26,-46.67,179.48,
     $ -46.34,191.59,-45.77,203.56,-44.97,215.44,-43.84,227.19,
     $ -42.37,238.64,-40.61,249.63,-38.71,260.15,-36.81,270.31,
     $ -34.97,280.25,-33.17,290.06,-31.40,299.76,-29.67,309.36,
     $ -27.95,318.87,-26.14,328.27,-24.18,337.37,-22.21,345.93,
     $ -20.72,353.82,-20.45,  1.14,-21.84,  8.24,-24.65, 15.59,
     $ -28.17, 23.55,-31.77, 32.30,-35.03, 41.81,-37.74, 51.93/
C
      DATA((A(I,J, 63),I=1,2),J=1,36)/
     $ -41.08, 61.73,-42.50, 72.27,-43.34, 82.63,-43.77, 92.58,
     $ -44.09,102.11,-44.58,111.46,-45.39,121.05,-46.46,131.29,
     $ -47.55,142.39,-48.40,154.26,-48.86,166.61,-48.90,179.08,
     $ -48.60,191.46,-48.03,203.70,-47.19,215.80,-46.03,227.71,
     $ -44.52,239.29,-42.74,250.37,-40.82,260.96,-38.89,271.16,
     $ -37.00,281.11,-35.15,290.91,-33.33,300.58,-31.55,310.14,
     $ -29.78,319.61,-27.94,328.94,-25.97,337.94,-24.03,346.37,
     $ -22.59,354.10,-22.33,  1.26,-23.64,  8.21,-26.29, 15.41,
     $ -29.67, 23.25,-33.16, 31.88,-36.35, 41.29,-39.02, 51.31/
C
      DATA((A(I,J, 64),I=1,2),J=1,36)/
     $ -42.30, 61.00,-43.74, 71.40,-44.64, 81.62,-45.18, 91.46,
     $ -45.62,100.92,-46.24,110.24,-47.17,119.85,-48.34,130.14,
     $ -49.52,141.33,-50.47,153.34,-51.01,165.89,-51.12,178.63,
     $ -50.86,191.31,-50.29,203.84,-49.41,216.19,-48.21,228.29,
     $ -46.67,239.99,-44.87,251.18,-42.92,261.83,-40.95,272.07,
     $ -39.01,282.03,-37.11,291.81,-35.25,301.45,-33.42,310.98,
     $ -31.60,320.39,-29.72,329.64,-27.74,338.52,-25.84,346.81,
     $ -24.45,354.39,-24.20,  1.40,-25.42,  8.22,-27.93, 15.29,
     $ -31.16, 22.99,-34.53, 31.51,-37.64, 40.80,-40.26, 50.71/
C
      DATA((A(I,J, 65),I=1,2),J=1,36)/
     $ -43.49, 60.26,-44.94, 70.51,-45.90, 80.59,-46.54, 90.30,
     $ -47.12, 99.68,-47.87,108.96,-48.92,118.58,-50.19,128.91,
     $ -51.47,140.18,-52.51,152.33,-53.15,165.09,-53.34,178.12,
     $ -53.12,191.14,-52.54,203.99,-51.64,216.61,-50.39,228.91,
     $ -48.82,240.76,-46.98,252.05,-45.00,262.77,-42.99,273.05,
     $ -41.01,283.01,-39.06,292.77,-37.15,302.38,-35.28,311.86,
     $ -33.42,321.21,-31.50,330.36,-29.52,339.12,-27.65,347.26,
     $ -26.32,354.70,-26.06,  1.57,-27.21,  8.26,-29.57, 15.21,
     $ -32.65, 22.79,-35.88, 31.18,-38.90, 40.34,-41.47, 50.11/
C
      DATA((A(I,J, 66),I=1,2),J=1,36)/
     $ -44.64, 59.52,-46.11, 69.60,-47.13, 79.52,-47.87, 89.09,
     $ -48.58, 98.37,-49.46,107.62,-50.63,117.23,-52.01,127.59,
     $ -53.39,138.93,-54.53,151.23,-55.27,164.22,-55.54,177.56,
     $ -55.37,190.93,-54.80,204.14,-53.86,217.06,-52.57,229.59,
     $ -50.95,241.60,-49.08,252.99,-47.07,263.79,-45.02,274.09,
     $ -42.99,284.06,-41.00,293.80,-39.05,303.36,-37.14,312.79,
     $ -35.23,322.07,-33.28,331.11,-31.29,339.73,-29.46,347.73,
     $ -28.18,355.02,-27.93,  1.77,-28.99,  8.34,-31.21, 15.17,
     $ -34.12, 22.63,-37.23, 30.89,-40.14, 39.91,-42.65, 49.54/
C
      DATA((A(I,J, 67),I=1,2),J=1,36)/
     $ -45.77, 58.78,-47.25, 68.67,-48.33, 78.41,-49.17, 87.84,
     $ -50.00, 97.02,-51.02,106.21,-52.30,115.79,-53.79,126.17,
     $ -55.28,137.58,-56.53,150.02,-57.38,163.26,-57.74,176.94,
     $ -57.61,190.70,-57.04,204.30,-56.08,217.56,-54.75,230.34,
     $ -53.09,242.51,-51.17,254.03,-49.12,264.89,-47.03,275.22,
     $ -44.96,285.19,-42.93,294.90,-40.93,304.41,-38.98,313.77,
     $ -37.03,322.96,-35.05,331.88,-33.07,340.36,-31.28,348.21,
     $ -30.04,355.36,-29.80,  1.99,-30.78,  8.45,-32.85, 15.18,
     $ -35.60, 22.51,-38.56, 30.63,-41.37, 39.50,-43.80, 48.97/
C
      DATA((A(I,J, 68),I=1,2),J=1,36)/
     $ -46.88, 58.02,-48.38, 67.71,-49.51, 77.26,-50.45, 86.53,
     $ -51.40, 95.60,-52.54,104.71,-53.94,114.27,-55.54,124.65,
     $ -57.14,136.11,-58.50,148.69,-59.46,162.18,-59.91,176.22,
     $ -59.84,190.44,-59.29,204.48,-58.30,218.11,-56.92,231.17,
     $ -55.21,243.53,-53.26,255.16,-51.16,266.09,-49.03,276.44,
     $ -46.92,286.39,-44.84,296.07,-42.81,305.53,-40.81,314.81,
     $ -38.82,323.90,-36.82,332.69,-34.85,341.01,-33.11,348.70,
     $ -31.91,355.72,-31.66,  2.24,-32.57,  8.60,-34.49, 15.22,
     $ -37.08, 22.44,-39.89, 30.41,-42.58, 39.12,-44.95, 48.40/
C
      DATA((A(I,J, 69),I=1,2),J=1,36)/
     $ -47.98, 57.25,-49.48, 66.73,-50.67, 76.07,-51.70, 85.18,
     $ -52.77, 94.11,-54.03,103.15,-55.55,112.65,-57.26,123.01,
     $ -58.96,134.52,-60.44,147.23,-61.52,160.98,-62.07,175.43,
     $ -62.07,190.13,-61.53,204.67,-60.51,218.72,-59.08,232.09,
     $ -57.33,244.67,-55.33,256.41,-53.20,267.40,-51.02,277.77,
     $ -48.86,287.70,-46.74,297.32,-44.67,306.71,-42.63,315.90,
     $ -40.60,324.87,-38.59,333.52,-36.64,341.68,-34.94,349.21,
     $ -33.79,356.10,-33.54,  2.51,-34.36,  8.78,-36.14, 15.30,
     $ -38.56, 22.40,-41.22, 30.23,-43.80, 38.76,-46.08, 47.84/
C
      DATA((A(I,J, 70),I=1,2),J=1,36)/
     $ -49.07, 56.46,-50.58, 65.72,-51.82, 74.85,-52.94, 83.77,
     $ -54.12, 92.57,-55.50,101.50,-57.13,110.93,-58.94,121.26,
     $ -60.75,132.77,-62.36,145.60,-63.56,159.64,-64.22,174.53,
     $ -64.28,189.78,-63.76,204.87,-62.72,219.41,-61.24,233.13,
     $ -59.43,245.93,-57.39,257.80,-55.21,268.84,-52.99,279.22,
     $ -50.79,289.11,-48.63,298.67,-46.52,307.98,-44.44,317.06,
     $ -42.39,325.89,-40.37,334.37,-38.44,342.36,-36.78,349.74,
     $ -35.68,356.49,-35.42,  2.80,-36.16,  8.99,-37.80, 15.42,
     $ -40.05, 22.39,-42.56, 30.06,-45.01, 38.41,-47.21, 47.28/
C
      DATA((A(I,J, 71),I=1,2),J=1,36)/
     $ -50.15, 55.66,-51.67, 64.67,-52.96, 73.58,-54.16, 82.31,
     $ -55.45, 90.95,-56.94, 99.75,-58.68,109.09,-60.59,119.35,
     $ -62.51,130.85,-64.25,143.79,-65.58,158.11,-66.35,173.49,
     $ -66.49,189.35,-65.99,205.11,-64.93,220.20,-63.40,234.32,
     $ -61.53,247.35,-59.43,259.34,-57.20,270.44,-54.94,280.81,
     $ -52.70,290.66,-50.50,300.13,-48.36,309.33,-46.25,318.28,
     $ -44.17,326.95,-42.15,335.26,-40.25,343.07,-38.64,350.29,
     $ -37.57,356.91,-37.31,  3.13,-37.97,  9.23,-39.47, 15.56,
     $ -41.56, 22.42,-43.90, 29.92,-46.22, 38.07,-48.34, 46.72/
C
      DATA((A(I,J, 72),I=1,2),J=1,36)/
     $ -51.24, 54.83,-52.76, 63.60,-54.09, 72.26,-55.38, 80.78,
     $ -56.77, 89.25,-58.36, 97.91,-60.19,107.12,-62.20,117.27,
     $ -64.24,128.73,-66.10,141.74,-67.57,156.37,-68.46,172.27,
     $ -68.68,188.85,-68.22,205.34,-67.14,221.09,-65.55,235.69,
     $ -63.61,248.98,-61.45,261.09,-59.18,272.21,-56.88,282.55,
     $ -54.59,292.33,-52.36,301.70,-50.18,310.77,-48.05,319.58,
     $ -45.96,328.08,-43.94,336.19,-42.07,343.81,-40.51,350.86,
     $ -39.48,357.36,-39.20,  3.47,-39.79,  9.49,-41.15, 15.74,
     $ -43.07, 22.46,-45.26, 29.80,-47.44, 37.73,-49.47, 46.14/
C
      DATA((A(I,J, 73),I=1,2),J=1,36)/
     $ -52.34, 53.98,-53.85, 62.47,-55.23, 70.89,-56.60, 79.18,
     $ -58.07, 87.46,-59.75, 95.94,-61.68,104.99,-63.78,115.00,
     $ -65.92,126.36,-67.91,139.43,-69.51,154.34,-70.54,170.84,
     $ -70.86,188.26,-70.43,205.66,-69.33,222.17,-67.70,237.28,
     $ -65.68,250.86,-63.46,263.07,-61.14,274.19,-58.78,284.48,
     $ -56.46,294.16,-54.20,303.41,-51.99,312.32,-49.84,320.95,
     $ -47.74,329.25,-45.74,337.16,-43.90,344.58,-42.39,351.46,
     $ -41.40,357.83,-41.11,  3.85,-41.62,  9.79,-42.85, 15.94,
     $ -44.60, 22.53,-46.62, 29.69,-48.68, 37.40,-50.61, 45.56/
C
      DATA((A(I,J, 74),I=1,2),J=1,36)/
     $ -53.44, 53.09,-54.96, 61.30,-56.38, 69.45,-57.81, 77.50,
     $ -59.36, 85.55,-61.13, 93.84,-63.13,102.69,-65.31,112.49,
     $ -67.55,123.70,-69.67,136.77,-71.42,151.94,-72.61,169.12,
     $ -73.02,187.67,-72.62,206.15,-71.51,223.49,-69.82,239.18,
     $ -67.75,253.06,-65.44,265.35,-63.06,276.44,-60.67,286.63,
     $ -58.31,296.17,-56.01,305.25,-53.78,313.99,-51.61,322.41,
     $ -49.52,330.49,-47.54,338.18,-45.75,345.39,-44.29,352.09,
     $ -43.33,358.33,-43.03,  4.26,-43.46, 10.11,-44.56, 16.16,
     $ -46.15, 22.61,-48.01, 29.58,-49.93, 37.06,-51.77, 44.95/
C
      DATA((A(I,J, 75),I=1,2),J=1,36)/
     $ -54.57, 52.16,-56.08, 60.07,-57.53, 67.93,-59.02, 75.72,
     $ -60.64, 83.53,-62.47, 91.58,-64.54,100.18,-66.80,109.71,
     $ -69.13,120.71,-71.37,133.68,-73.30,149.03,-74.64,167.09,
     $ -75.16,186.94,-74.78,206.86,-73.61,225.28,-71.91,241.49,
     $ -69.76,255.66,-67.40,268.02,-64.95,278.99,-62.52,289.03,
     $ -60.12,298.40,-57.80,307.27,-55.55,315.78,-53.38,323.97,
     $ -51.30,331.81,-49.35,339.26,-47.61,346.25,-46.20,352.77,
     $ -45.27,358.87,-44.96,  4.69,-45.32, 10.46,-46.29, 16.40,
     $ -47.72, 22.70,-49.42, 29.48,-51.21, 36.71,-52.95, 44.32/
C
      DATA((A(I,J, 76),I=1,2),J=1,36)/
     $ -55.72, 51.18,-57.22, 58.77,-58.69, 66.33,-60.22, 73.83,
     $ -61.90, 81.37,-63.80, 89.14,-65.92, 97.44,-68.23,106.64,
     $ -70.66,117.31,-73.02,129.96,-75.11,145.56,-76.62,164.44,
     $ -77.27,185.86,-76.92,207.62,-75.70,227.42,-73.88,244.38,
     $ -71.73,258.78,-69.30,271.12,-66.81,281.94,-64.33,291.74,
     $ -61.91,300.86,-59.56,309.49,-57.31,317.73,-55.14,325.65,
     $ -53.08,333.22,-51.17,340.40,-49.47,347.16,-48.12,353.49,
     $ -47.22,359.44,-46.90,  5.16,-47.18, 10.83,-48.03, 16.65,
     $ -49.30, 22.80,-50.85, 29.36,-52.50, 36.34,-54.15, 43.66/
C
      DATA((A(I,J, 77),I=1,2),J=1,36)/
     $ -56.89, 50.14,-58.38, 57.39,-59.86, 64.62,-61.43, 71.81,
     $ -63.16, 79.05,-65.09, 86.49,-67.25, 94.40,-69.61,103.21,
     $ -72.11,113.42,-74.57,125.66,-76.82,141.23,-78.54,160.92,
     $ -79.35,184.33,-79.05,208.58,-77.77,230.17,-75.84,247.92,
     $ -73.56,262.47,-71.13,274.76,-68.60,285.34,-66.08,294.81,
     $ -63.64,303.61,-61.29,311.92,-59.03,319.86,-56.88,327.46,
     $ -54.85,334.73,-52.98,341.63,-51.35,348.14,-50.05,354.27,
     $ -49.18,  0.07,-48.84,  5.66,-49.06, 11.22,-49.78, 16.91,
     $ -50.91, 22.89,-52.31, 29.23,-53.83, 35.94,-55.38, 42.95/
C
      DATA((A(I,J, 78),I=1,2),J=1,36)/
     $ -58.09, 49.02,-59.55, 55.92,-61.04, 62.80,-62.64, 69.65,
     $ -64.40, 76.53,-66.35, 83.58,-68.53, 91.07,-70.93, 99.35,
     $ -73.44,108.83,-76.02,120.55,-78.44,135.75,-80.39,156.06,
     $ -81.41,182.03,-81.18,209.91,-79.80,233.93,-77.74,252.49,
     $ -75.35,266.99,-72.85,279.00,-70.30,289.26,-67.77,298.33,
     $ -65.32,306.69,-62.97,314.62,-60.73,322.18,-58.60,329.42,
     $ -56.61,336.36,-54.80,342.96,-53.23,349.21,-51.98,355.12,
     $ -51.15,  0.75,-50.79,  6.20,-50.94, 11.63,-51.55, 17.18,
     $ -52.54, 22.97,-53.79, 29.08,-55.19, 35.50,-56.64, 42.18/
C
      DATA((A(I,J, 79),I=1,2),J=1,36)/
     $ -59.32, 47.82,-60.74, 54.34,-62.24, 60.84,-63.84, 67.31,
     $ -65.61, 73.79,-67.56, 80.40,-69.75, 87.37,-72.16, 94.99,
     $ -74.68,103.67,-77.33,114.42,-79.91,128.65,-82.12,149.06,
     $ -83.44,178.30,-83.28,212.04,-81.77,239.43,-79.54,258.63,
     $ -77.04,272.70,-74.46,284.01,-71.91,293.84,-69.37,302.33,
     $ -66.93,310.18,-64.60,317.61,-62.39,324.73,-60.30,331.57,
     $ -58.36,338.14,-56.62,344.41,-55.11,350.37,-53.92,356.04,
     $ -53.12,  1.48,-52.75,  6.78,-52.84, 12.06,-53.34, 17.44,
     $ -54.20, 23.03,-55.31, 28.89,-56.58, 35.01,-57.93, 41.34/
C
      DATA((A(I,J, 80),I=1,2),J=1,36)/
     $ -60.57, 46.52,-61.96, 52.63,-63.44, 58.72,-65.04, 64.76,
     $ -66.78, 70.79,-68.74, 76.89,-70.91, 83.24,-73.25, 90.02,
     $ -75.80, 97.73,-78.48,107.04,-81.18,119.45,-83.67,138.42,
     $ -85.40,171.38,-85.36,215.98,-83.61,248.15,-81.18,267.10,
     $ -78.57,279.98,-75.94,290.13,-73.37,298.95,-70.87,306.90,
     $ -68.46,314.10,-66.17,320.95,-64.00,327.56,-61.97,333.94,
     $ -60.09,340.09,-58.42,345.99,-56.99,351.65,-55.86,357.06,
     $ -55.08,  2.28,-54.71,  7.40,-54.74, 12.51,-55.15, 17.70,
     $ -55.88, 23.07,-56.86, 28.65,-58.01, 34.45,-59.25, 40.43/
C
      DATA((A(I,J, 81),I=1,2),J=1,36)/
     $ -61.87, 45.08,-63.21, 50.76,-64.65, 56.39,-66.21, 61.97,
     $ -67.93, 67.49,-69.85, 73.01,-71.98, 78.62,-74.25, 84.50,
     $ -76.75, 90.91,-79.41, 98.26,-82.16,107.65,-84.88,122.13,
     $ -87.20,155.03,-87.38,226.04,-85.20,263.08,-82.55,278.95,
     $ -79.87,289.29,-77.24,297.62,-74.69,305.06,-72.23,312.14,
     $ -69.87,318.52,-67.64,324.70,-65.55,330.71,-63.59,336.56,
     $ -61.80,342.24,-60.21,347.74,-58.86,353.05,-57.79,358.18,
     $ -57.05,  3.17,-56.66,  8.07,-56.64, 12.97,-56.97, 17.95,
     $ -57.58, 23.06,-58.44, 28.36,-59.46, 33.82,-60.62, 39.41/
C
      DATA((A(I,J, 82),I=1,2),J=1,36)/
     $ -63.19, 43.49,-64.46, 48.69,-65.86, 53.84,-67.36, 58.90,
     $ -69.04, 63.84,-70.90, 68.69,-72.90, 73.49,-75.11, 78.32,
     $ -77.51, 83.17,-80.06, 88.13,-82.73, 93.35,-85.47, 99.21,
     $ -88.24,108.23,-88.94,275.29,-86.19,288.53,-83.48,295.05,
     $ -80.84,300.89,-78.28,306.57,-75.81,312.22,-73.43,317.92,
     $ -71.16,323.51,-69.03,328.88,-67.02,334.21,-65.17,339.48,
     $ -63.48,344.65,-61.98,349.70,-60.71,354.63,-59.71,359.43,
     $ -59.01,  4.14,-58.62,  8.80,-58.56, 13.46,-58.80, 18.19,
     $ -59.31, 23.03,-60.05, 28.00,-60.96, 33.09,-62.02, 38.26/
C
      DATA((A(I,J, 83),I=1,2),J=1,36)/
     $ -64.54, 41.70,-65.74, 46.40,-67.04, 51.02,-68.49, 55.49,
     $ -70.09, 59.79,-71.85, 63.88,-73.73, 67.83,-75.80, 71.45,
     $ -78.02, 74.61,-80.37, 76.97,-82.80, 77.79,-85.23, 74.57,
     $ -87.42, 56.36,-87.98,353.36,-86.13,320.48,-83.77,314.24,
     $ -81.36,314.41,-78.98,316.88,-76.67,320.43,-74.45,324.59,
     $ -72.30,329.11,-70.29,333.56,-68.41,338.12,-66.68,342.73,
     $ -65.11,347.34,-63.72,351.90,-62.55,356.40,-61.62,  0.84,
     $ -60.96,  5.23,-60.57,  9.60,-60.48, 13.98,-60.65, 18.42,
     $ -61.07, 22.93,-61.70, 27.54,-62.50, 32.22,-63.46, 36.96/
C
      DATA((A(I,J, 84),I=1,2),J=1,36)/
     $ -65.91, 39.68,-67.00, 43.85,-68.22, 47.87,-69.58, 51.70,
     $ -71.06, 55.29,-72.67, 58.63,-74.40, 61.61,-76.28, 63.98,
     $ -78.27, 65.46,-80.32, 65.52,-82.37, 63.02,-84.27, 55.35,
     $ -85.70, 37.59,-86.05,  8.56,-85.07,344.49,-83.35,332.88,
     $ -81.36,328.68,-79.29,328.15,-77.23,329.53,-75.22,332.04,
     $ -73.27,335.24,-71.41,338.78,-69.69,342.49,-68.11,346.38,
     $ -66.68,350.36,-65.42,354.38,-64.35,358.41,-63.50,  2.43,
     $ -62.89,  6.45,-62.52, 10.47,-62.40, 14.52,-62.51, 18.61,
     $ -62.85, 22.76,-63.38, 26.96,-64.08, 31.20,-64.93, 35.46/
C
      DATA((A(I,J, 85),I=1,2),J=1,36)/
     $ -67.28, 37.40,-68.27, 40.95,-69.38, 44.32,-70.60, 47.47,
     $ -71.94, 50.31,-73.36, 52.88,-74.90, 54.85,-76.53, 56.05,
     $ -78.21, 56.13,-79.90, 54.59,-81.50, 50.53,-82.87, 42.63,
     $ -83.81, 29.86,-84.03, 13.54,-83.49,358.35,-82.34,347.89,
     $ -80.85,342.05,-79.18,339.51,-77.45,339.14,-75.72,340.12,
     $ -74.02,342.03,-72.37,344.54,-70.85,347.36,-69.45,350.47,
     $ -68.18,353.77,-67.06,357.19,-66.12,  0.69,-65.36,  4.23,
     $ -64.81,  7.82,-64.46, 11.43,-64.32, 15.08,-64.39, 18.77,
     $ -64.65, 22.49,-65.09, 26.24,-65.69, 29.99,-66.42, 33.73/
C
      DATA((A(I,J, 86),I=1,2),J=1,36)/
     $ -68.67, 34.74,-69.53, 37.64,-70.49, 40.33,-71.55, 42.75,
     $ -72.68, 44.88,-73.89, 46.62,-75.19, 47.68,-76.52, 47.92,
     $ -77.86, 47.08,-79.15, 44.81,-80.32, 40.67,-81.26, 34.30,
     $ -81.86, 25.75,-82.01, 15.92,-81.69,  6.43,-80.95,358.73,
     $ -79.91,353.36,-78.67,350.16,-77.32,348.70,-75.93,348.55,
     $ -74.53,349.34,-73.17,350.82,-71.86,352.76,-70.67,355.06,
     $ -69.59,357.63,-68.64,  0.40,-67.83,  3.30,-67.18,  6.31,
     $ -66.70,  9.39,-66.38, 12.52,-66.25, 15.69,-66.28, 18.90,
     $ -66.47, 22.13,-66.82, 25.35,-67.31, 28.55,-67.93, 31.70/
C
      DATA((A(I,J, 87),I=1,2),J=1,36)/
     $ -70.06, 31.64,-70.75, 33.84,-71.53, 35.82,-72.38, 37.50,
     $ -73.28, 38.99,-74.25, 39.92,-75.25, 40.27,-76.25, 39.89,
     $ -77.23, 38.67,-78.13, 36.42,-78.92, 33.07,-79.52, 28.58,
     $ -79.89, 23.17,-79.99, 17.27,-79.80, 11.50,-79.35,  6.40,
     $ -78.67,  2.35,-77.82,359.49,-76.86,357.73,-75.83,356.93,
     $ -74.78,356.94,-73.73,357.58,-72.71,358.70,-71.76,  0.18,
     $ -70.90,  2.01,-70.14,  4.07,-69.49,  6.31,-68.96,  8.69,
     $ -68.56, 11.17,-68.30, 13.73,-68.17, 16.33,-68.18, 18.96,
     $ -68.31, 21.60,-68.58, 24.22,-68.96, 26.79,-69.46, 29.28/
C
      DATA((A(I,J, 88),I=1,2),J=1,36)/
     $ -71.42, 28.01,-71.92, 29.48,-72.48, 30.74,-73.08, 31.85,
     $ -73.73, 32.60,-74.39, 32.94,-75.07, 32.85,-75.73, 32.26,
     $ -76.35, 31.13,-76.91, 29.44,-77.37, 27.19,-77.72, 24.46,
     $ -77.93, 21.36,-77.99, 18.10,-77.88, 14.86,-77.62, 11.89,
     $ -77.22,  9.33,-76.71,  7.30,-76.11,  5.84,-75.45,  4.94,
     $ -74.76,  4.57,-74.06,  4.65,-73.37,  5.12,-72.70,  5.91,
     $ -72.09,  6.96,-71.55,  8.29,-71.08,  9.81,-70.70, 11.47,
     $ -70.40, 13.25,-70.20, 15.11,-70.10, 17.02,-70.09, 18.95,
     $ -70.18, 20.89,-70.37, 22.79,-70.64, 24.64,-70.99, 26.39/
C
      DATA((A(I,J, 89),I=1,2),J=1,36)/
     $ -72.74, 23.84,-73.01, 24.58,-73.31, 25.18,-73.63, 25.59,
     $ -73.97, 25.83,-74.31, 25.85,-74.65, 25.65,-74.97, 25.21,
     $ -75.26, 24.55,-75.51, 23.66,-75.72, 22.58,-75.88, 21.35,
     $ -75.96, 20.00,-75.99, 18.60,-75.94, 17.21,-75.82, 15.90,
     $ -75.65, 14.71,-75.42, 13.70,-75.14, 12.89,-74.83, 12.31,
     $ -74.49, 11.95,-74.15, 11.81,-73.80, 11.90,-73.46, 12.17,
     $ -73.14, 12.63,-72.85, 13.23,-72.59, 13.95,-72.38, 14.77,
     $ -72.21, 15.72,-72.10, 16.73,-72.04, 17.79,-72.03, 18.87,
     $ -72.07, 19.94,-72.17, 20.99,-72.32, 21.99,-72.51, 22.95/
C
C 
C******************************************************************* 
C  SAVE ORIGINAL INPUTS
C******************************************************************* 
      GGLAT=OLDLAT 
      GGLON=OLDLON 
C******************************************************************* 
C     REDUCE GGLAT TO THE RANGE -90 TO +90 DEGREES
C******************************************************************* 
 6000 IF(GGLAT.LE.90.) GO TO 6001
      GGLAT=180.-GGLAT
      GGLON=GGLON+180.
      GO TO 6000
 6001 IF(GGLAT.GE.-90.) GO TO 6002
      GGLAT=-180.-GGLAT
      GGLON=GGLON+180.
      GO TO 6000
 6002 CONTINUE
C***********************************************************************
C     REDUCE GGLON TO .LT. 360 DEGREES (POSITIVE OR NEGATIVE) 
C***********************************************************************
 6666 GGLON = AMOD(GGLON,360.)
C***********************************************************************
C     CHECK TO SEE IF GGLON .GT.0, IF NOT CORRECT TO BE .GT. ZERO
C***********************************************************************
      IF(GGLON .LT. 0.0)GGLON = GGLON + 360.0
      I = IFIX((90.0 - GGLAT)/2.0)
      J = IFIX(GGLON/10.) + 1
C***********************************************************************
C     CHECK TO SEE IF I IS WITHIN BOUNDS
C***********************************************************************
      IF(I.GT.0.AND.I.LT.89)GO TO 3 
C***********************************************************************
C     SET TO INTERPOLATE TO THE POLES (N OR S GEOGRAPHIC)
C***********************************************************************
      IF (J .GT. 36) J=J-36
      IF (J .LT.  1) J=J+36
      K=J+1
      IF (K .GT. 36) K=K-36
      IF (I .GT.  0) GO TO 2 
        I=0
        X1LAT=CGMNLA
        X1LON=CGMNLO
        X2LAT=A(1,J,I+1)
        X2LON=A(2,J,I+1)
        X3LAT=A(1,K,I+1)
        X3LON=A(2,K,I+1)
        X4LAT=CGMNLA
        X4LON=CGMNLO
        GO TO 5
    2 I=89
      X1LAT=A(1,J,I)
      X1LON=A(2,J,I)
      X2LAT=CGMSLA 
      X2LON=CGMSLO 
      X3LAT=CGMSLA 
      X3LON=CGMSLO 
      X4LAT=A(1,K,I)
      X4LON=A(2,K,I)
      GO TO 5
C***********************************************************************
C     STATEMENT 3... CHECK TO SEE IF J IS WITHIN BOUNDS.  IF OUT OF
C    BOUNDS, RESTORE TO IN BOUNDS 
C***********************************************************************
    3 IF(J.GT.36)J = J - 36
      IF(J.LT.1)J = J + 36
C***********************************************************************
C     FIND CGLAT AND CGLON OF THE FOUR CORNERS OF RECTENGLE WITHIN WHICH
C     AND GGLON FALL.  THE CORNERS OF THE RECTANGLE ARE X1, X2, X3, AND 
C     REFERS TO THE NORTHWESTERLY MOST POINT OF THE RECTANGLE.  THE LABE
C     IN A COUNTERCLOCKWISE MANNER.
C***********************************************************************
      X1LAT = A(1,J,I)
      X1LON = A(2,J,I)
      X2LAT = A(1,J,I+1)
      X2LON = A(2,J,I+1)
C***********************************************************************
C     CHECK TO SEE IF THE EASTERLY EDGE OF THE RECTANGLE IS WITHIN THE L
C     ARGUMENT BOUNDS OF ARRAY A. 
C***********************************************************************
      K = J + 1
      IF(K.GT.36)K = K - 36
      X3LAT = A(1,K,I+1)
      X3LON = A(2,K,I+1)
      X4LAT = A(1,K,I)
      X4LON = A(2,K,I)
C***********************************************************************
C     ELIMINATE THE DISCONTINUITIES IN THE X1, X2, X3, AND X4 LONGITUDES
C     WOULD OCCUR IF THE PRIME MERIDIAN OF THE CORRECTED GEOMAGNETIC COO
C     SYSTEM PASSED THROUGH RECTANGLE X1, X2, X3, X4. 
C***********************************************************************
5     Y = AMAX1(X1LON,X2LON,X3LON,X4LON)
      IF(ABS(Y-X1LON).GT.180.0)X1LON = X1LON + 360.0
      IF(ABS(Y-X2LON).GT.180.0)X2LON = X2LON + 360.0
      IF(ABS(Y-X3LON).GT.180.0)X3LON = X3LON + 360.0
      IF(ABS(Y-X4LON).GT.180.0)X4LON = X4LON + 360.0
C***********************************************************************
C     CALCULATE THE SOUTHERN AND THE WESTWARD BOUNDARIES (GEOGRAPHIC LAT
C     AND LONGITUDE) OF THE RECTANGLE. 
C***********************************************************************
      EGGLA = FLOAT(-2*I + 88)
      WGGLO = FLOAT(10*J - 10)
C***********************************************************************
C     CALCULATE THE COEFFICIENTS OF THE INTERPOLATION EQUATION.  THESE
C     COEFFICIENTS REPRESENT THE FRACTIONAL PART OF THE BOX THE POINT GG
C     GGLON IS FROM THE SOUTHERN AND THE WESTWARD BOUNDARIES OF THE RECT
C***********************************************************************
      ALPHA = (GGLAT - EGGLA)/2.0
      BETA = (GGLON - WGGLO)/10.
C***********************************************************************
C     NOW CALCULATE THE CORRECTED GEOMAGNETIC COORDINATES THAT CORRESPON
C     GEOGRAPHIC COORDINATES OF THE INPUT POINT (GGLAT,GGLON) 
C***********************************************************************
      CGLAT = X2LAT + ALPHA*(X1LAT - X2LAT) + BETA*(X3LAT - X2LAT) + 
     1(ALPHA*BETA)*(X4LAT + X2LAT - X1LAT - X3LAT)
      CGLON = X2LON + ALPHA*(X1LON - X2LON) + BETA*(X3LON - X2LON) + 
     1(ALPHA*BETA)*(X4LON + X2LON - X1LON - X3LON)
C***********************************************************************
C     CHECK TO DETERMINE IF THE CORRECTED GEOMAGNETIC LONGITUDE IS LESS 
C     DEGREES.  IF IT IS NOT REDUCE THE CALCULATED VALUE BY 360.0 DEGREE
C***********************************************************************
      IF(CGLON.GT.360.0)CGLON = CGLON - 360.0
    4 RETURN
      END
